@@ -1,11 +1,8 @@
-use crate::BlockHeight;
-
 // Block height code ported from C# implementations of driver code by gdkchan.
 // The code can be found here: https://github.com/KillzXGaming/Switch-Toolbox/pull/419#issuecomment-959980096
 // This comes from the Ryujinx emulator: https://github.com/Ryujinx/Ryujinx/blob/master/LICENSE.txt.
+use crate::BlockHeight;
 
-// TODO: Separate module for this code?
-// TODO: Document that this is height in bytes.
 /// Calculates the block height parameter to use for the first mip level if no block height is specified.
 ///
 /// # Examples
@@ -45,8 +42,6 @@ pub fn block_height_mip0(height: usize) -> BlockHeight {
     }
 }
 
-// TODO: Rename these inputs to match the conventions of this library.
-// TODO: Rework this example.
 /// Calculates the block height parameter for the given mip level.
 ///
 /// # Examples
@@ -66,19 +61,14 @@ let mipmap_count = 5;
 
 let block_height_mip0 = block_height_mip0(div_round_up(height, 4));
 for mip in 0..mipmap_count {
-    let mip_height = div_round_up(height >> mip, 4);
+    let mip_height = std::cmp::max(div_round_up(height >> mip, 4), 1);
 
     // The block height will likely change for each mip level.
     let mip_block_height = mip_block_height(mip_height, block_height_mip0);
 }
 ```
  */
-pub fn mip_block_height(
-    // TODO: It's more consistent with the rest of the API to explicitly pass in the mip height?
-    // TODO: Should the other examples change to div_round_up instead of using "/ 4"?
-    mip_height: usize,
-    block_height_mip0: BlockHeight,
-) -> BlockHeight {
+pub fn mip_block_height(mip_height: usize, block_height_mip0: BlockHeight) -> BlockHeight {
     let mut block_height = block_height_mip0 as usize;
     while mip_height <= (block_height / 2) * 8 && block_height > 1 {
         block_height /= 2;
